==> Cosmos.uv6.25.tar.gz: Tracking/cobservation.f <==
c        observation routine.  Interface to a user Hook.
c
      subroutine cobservation(id)
      implicit none
#include  "Zglobalc.h"
#include  "Ztrack.h"
#include  "Ztrackp.h"
#include  "Ztrackv.h"
#include  "Zobs.h"
#include  "Zobsp.h"
#include  "Zobsv.h"

      integer id !  input. 1 ==> the ptcl goes out from BorderHeightH
                 !         2 ==> the ptcl is observed at an observation level
                 !         3 ==> the ptcl reached at BorderHeightL
                 !          calles below happen only if DETAILED_TRACKING == 1
                 !         4 ==> the ptcl is going to make an interaction
                 !         5 ==> the ptcl is going to die
                 !         6 ==> the ptcl is being discarded because path >
                 !               limit  
                 !         7 ==> the ptcl is being discarded by angle limit
                 !               However, ondimentional mode  will not 
                 !               call this.
                 !         8 ==> the ptcl moved a step. 

      record /track/oTrack

      integer  iwhere

#if LABELING > 0
cc      if(MovedTrack.where .eq. 1 .and. id .eq. 2) then
      if(MovedTrack.where .le. 31 .and. id .eq. 2) then
         if( MovedTrack.vec.coszenith .lt. 0. ) then
c             upgoing.            
cc            MovedTrack.info = MovedTrack.info + 1
            iwhere=MovedTrack.where
c               set bit for where-th bit.
            call ksetbit( MovedTrack.info,  iwhere )
         endif
      endif
#endif
      if(id .eq. 2) then
         oTrack = MovedTrack
c         no coord. conv. is made unless the ptcl is at observation
c         level.
c 
c           convert time into ns
         if(TimeStructure .and. ObsPlane .ge. 1 .and. ObsPlane .le. 2) 
     *    then
            oTrack.t = ( oTrack.t  - ObsSites(oTrack.where).minitime )
     *              /c *Tonsec
         endif

c          convert coordinate and direction cos. 
c          if ObsPlane < 0, no conversion. 
         if(ObsPlane .eq. horizontal) then

            call cxyz2det(ObsSites(oTrack.where).pos.xyz, 
     *                 oTrack.pos.xyz, oTrack.pos.xyz)
c       
            call cxyz2detD(oTrack.vec.w, oTrack.vec.w)

         elseif(ObsPlane .eq. perpendicular) then

            call cxyz2prim(ObsSites(oTrack.where).pos.xyz, 
     *                 oTrack.pos.xyz, oTrack.pos.xyz)
            call cxyz2primD(oTrack.vec.w, oTrack.vec.w)
         endif
c          call user routine      
         call chookObs(oTrack, id)
      else
c          The user may change the energy to discard the
c          particle
         call chookObs(MovedTrack,id)
      endif
      end

==> Cosmos.uv6.50.tar.gz: Tracking/cobservation.f <==
c        observation routine.  Interface to a user Hook.
c
      subroutine cobservation(id)
      implicit none
#include  "Zglobalc.h"
#include  "Ztrack.h"
#include  "Ztrackp.h"
#include  "Ztrackv.h"
#include  "Zobs.h"
#include  "Zobsp.h"
#include  "Zobsv.h"

      integer id !  input. 1 ==> the ptcl goes out from BorderHeightH
                 !         2 ==> the ptcl is observed at an observation level
                 !         3 ==> the ptcl reached at BorderHeightL
                 !          calles below happen only if DETAILED_TRACKING == 1
                 !         4 ==> the ptcl is going to make an interaction
                 !         5 ==> the ptcl is going to die
                 !         6 ==> the ptcl is being discarded because path >
                 !               limit  
                 !         7 ==> the ptcl is being discarded by angle limit
                 !               However, ondimentional mode  will not 
                 !               call this.
                 !         8 ==> the ptcl moved a step. 

      record /track/oTrack

      integer  iwhere

#if LABELING > 0
      if( MovedTrack.vec.coszenith .lt. 0. ) then
c             upgoing.       
         if(MovedTrack.where .eq. 1 .or. MovedTrack.where .eq. 2 .and.
     *        id .eq. 2) then
cc      if(MovedTrack.where .le. 31 .and. id .eq. 2) then
            if(MovedTrack.where .eq. 1) then
               MovedTrack.info = MovedTrack.info + 1
            else
               MovedTrack.info = MovedTrack.info + 65336
            endif
cc            iwhere=MovedTrack.where
c               set bit for where-th bit.
c            call ksetbit( MovedTrack.info,  iwhere )
         endif
      endif
#endif
      if(id .eq. 2) then
         oTrack = MovedTrack
c         no coord. conv. is made unless the ptcl is at observation
c         level.
c 
c           convert time into ns
         if(TimeStructure .and. ObsPlane .ge. 1 .and. ObsPlane .le. 2) 
     *    then
            oTrack.t = ( oTrack.t  - ObsSites(oTrack.where).minitime )
     *              /c *Tonsec
         endif

c          convert coordinate and direction cos. 
c          if ObsPlane < 0, no conversion. 
         if(ObsPlane .eq. horizontal) then

            call cxyz2det(ObsSites(oTrack.where).pos.xyz, 
     *                 oTrack.pos.xyz, oTrack.pos.xyz)
c       
            call cxyz2detD(oTrack.vec.w, oTrack.vec.w)

         elseif(ObsPlane .eq. perpendicular) then

            call cxyz2prim(ObsSites(oTrack.where).pos.xyz, 
     *                 oTrack.pos.xyz, oTrack.pos.xyz)
            call cxyz2primD(oTrack.vec.w, oTrack.vec.w)
         endif
c          call user routine      
         call chookObs(oTrack, id)
      else
c          The user may change the energy to discard the
c          particle
         call chookObs(MovedTrack,id)
      endif
      end
